@@ -1,6 +1,6 @@
-//! This module holds all the traits that have to be implemented for 
+//! This module holds all the traits that have to be implemented for
 //! the agent to be a plugable compontent.
-//! 
+//!
 //! The following mental model is used to the api design.
 //!
 //! There will be constructor functions that construct and run the simulation automatically. These
@@ -9,12 +9,12 @@
 //! with only a single agent type.
 //!
 //! The point of the simulations is to add some form of random sequencing. This means there will
-//! need to be multiple runs of the simulation with the same input parameters. One simulation run 
-//! will be fully separate of another simulation run, making a multiprocess execution model a very 
-//! good candidate for speeding up the program. 
+//! need to be multiple runs of the simulation with the same input parameters. One simulation run
+//! will be fully separate of another simulation run, making a multiprocess execution model a very
+//! good candidate for speeding up the program.
 //!
 //! The process will look something like this:
-//! 
+//!
 //!
 //! /*                  Environment
 //!                         |
@@ -50,22 +50,27 @@
 //!                                 Agent_3.collect() ]
 //! */
 
-
 pub trait Agent {
     ///
-    fn generate() -> Result<Box<Self>, &'static str> where Self: Sized;
+    fn generate() -> Result<Box<Self>, &'static str>
+    where
+        Self: Sized;
 
     ///
     fn collect(&self) -> Result<(), &'static str>;
 
     ///
     fn tick(&mut self) -> Result<(), &'static str>;
-}
 
+    //
+    fn clean(&self) -> Result<(), &'static str>;
+}
 
 pub trait Environment {
     ///
-    fn generate(pop: Vec<Box<dyn Agent>>) -> Result<Box<Self>, &'static str> where Self: Sized;
+    fn generate(pop: Vec<Box<dyn Agent>>) -> Result<Box<Self>, &'static str>
+    where
+        Self: Sized;
 
     ///
     fn collect(&self) -> Result<(), &'static str>;
@@ -73,9 +78,12 @@ pub trait Environment {
     ///
     fn tick(&mut self) -> Result<(), &'static str>;
 
+    //
+    fn clean(&self) -> Result<(), &'static str>;
+
     //
     fn add_agent(&mut self, agent: Box<dyn Agent>) -> Result<(), &'static str>;
 
     //
-    fn add_agents(&mut self, agents: Vec<Box<dyn Agent>>) -> Result<() , &'static str>;
-}
\ No newline at end of file
+    fn add_agents(&mut self, agents: Vec<Box<dyn Agent>>) -> Result<(), &'static str>;
+}
